@@ -9,13 +9,20 @@ const APP_NAME: &str = "hello world";
 
 fn main() -> Result<(), Box<dyn Error>> {
     SimpleLogger::new().init()?;
-    System::new(APP_NAME)?.run((), |_, ui, _| {
-        Window::new(im_str!("Hello world"))
+    let mut value = 0;
+    let choices = ["test test this is 1", "test test this is 2"];
+    System::new(APP_NAME)?.run((), move |_, ui, _| {
+        Window::new("Hello world")
             .size([300.0, 100.0], Condition::FirstUseEver)
             .build(ui, || {
-                ui.text(im_str!("Hello world!"));
-                ui.text(im_str!("こんにちは世界！"));
-                ui.text(im_str!("This...is...imgui-rs!"));
+                ui.text_wrapped("Hello world!");
+                ui.text_wrapped("こんにちは世界！");
+                if ui.button(choices[value]) {
+                    value += 1;
+                    value %= 2;
+                }
+
+                ui.button("This...is...imgui-rs!");
                 ui.separator();
                 let mouse_pos = ui.io().mouse_pos;
                 ui.text(format!(
